@@ -13,8 +13,9 @@ use URI;
 use URI::db;
 use URI::QueryParam;
 
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 
+has 'auto_migrate';
 has dsn => sub { _url_from_file(shift->_tempfile)->dbi_dsn };
 has max_connections => 5;
 has migrations      => sub {
@@ -86,6 +87,8 @@ sub _dequeue {
     $dbh->do('pragma journal_mode=WAL');
     $dbh->do('pragma synchronous=NORMAL');
   }
+  ++$self->{migrated} and $self->migrations->migrate
+    if !$self->{migrated} && $self->auto_migrate;
   $self->emit(connection => $dbh);
   return $dbh;
 }
@@ -138,6 +141,10 @@ Mojo::SQLite - A tiny Mojolicious wrapper for SQLite
   # Insert another row and return the generated id
   say $db->query('insert into names (name) values (?)', 'Daniel')
     ->last_insert_id;
+  
+  # JSON roundtrip
+  say $db->query('select ? as foo', {json => {bar => 'baz'}})
+    ->expand(json => 'foo')->hash->{foo}{bar};
 
   # Select one row at a time
   my $results = $db->query('select * from names');
@@ -146,8 +153,7 @@ Mojo::SQLite - A tiny Mojolicious wrapper for SQLite
   }
 
   # Select all rows
-  $db->query('select * from names')
-    ->hashes->map(sub { $_->{name} })->join("\n")->say;
+  say $_->{name} for $db->query('select * from names')->hashes->each;
 
   # Send and receive notifications non-blocking
   $sql->pubsub->listen(foo => sub {
@@ -175,13 +181,12 @@ gracefully by holding on to them only for short amounts of time.
   use Mojolicious::Lite;
   use Mojo::SQLite;
 
-  helper sqlite =>
-    sub { state $sql = Mojo::SQLite->new('sqlite:sqlite.db') };
+  helper sqlite => sub { state $sql = Mojo::SQLite->new('sqlite:sqlite.db') };
 
   get '/' => sub {
     my $c  = shift;
     my $db = $c->sqlite->db;
-    $c->render(json => $db->query('select datetime("now","localtime") as time')->hash);
+    $c->render(json => $db->query('select datetime("now","localtime") as now')->hash);
   };
 
   app->start;
@@ -239,6 +244,14 @@ Emitted when a new database connection has been established.
 
 L<Mojo::SQLite> implements the following attributes.
 
+=head2 auto_migrate
+
+  my $bool = $sql->auto_migrate;
+  $sql     = $sql->auto_migrate($bool);
+
+Automatically migrate to the latest database schema with L</"migrations">, as
+soon as the first database connection has been established.
+
 =head2 dsn
 
   my $dsn = $sql->dsn;
