@@ -3,7 +3,7 @@ use Mojo::Base 'Mojo::EventEmitter';
 
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 
 has 'poll_interval';
 has 'sqlite';
@@ -52,7 +52,7 @@ sub _db {
       eval { $self->_db };
     }
   );
-  $db->listen($_) for keys %{$self->{chans}}, 'mojo_sqlite_pubsub';
+  $db->listen($_) for keys %{$self->{chans}}, 'mojo.pubsub';
   $self->emit(reconnect => $db);
 
   return $db;
